import "@picocss/pico/css/pico.min.css";
import "./style.css";
import { setupRequestPage } from "./routes/request.ts";
import { setupSendPage } from "./routes/send.ts";
import { setupReceivePage } from "./routes/receive.ts";

const start = () => {
  const fragmentData = new URLSearchParams(window.location.hash.slice(1));
  const appElement = document.querySelector<HTMLElement>("#app");

  if (!appElement) {
    throw new Error("No app element found");
  }

  // If the URL contains the 'p', 'iv', and 'm' parameters, then the receiver page is set up
  if (
    fragmentData.has("p") &&
    fragmentData.has("iv") &&
    fragmentData.has("m")
  ) {
    setupReceivePage(appElement, {
      p: decodeURIComponent(fragmentData.get("p")!),
      iv: decodeURIComponent(fragmentData.get("iv")!),
      m: decodeURIComponent(fragmentData.get("m")!),
    });
    return;
  }

  // If the URL contains the 'p' parameter, then the sender page is set up
  if (fragmentData.has("p")) {
    setupSendPage(appElement, fragmentData.get("p")!);
    return;
  }

  // Otherwise, the request page is set up
  setupRequestPage(appElement);
};

start();
