import { retrieveOrGenerateKeyPair } from "../utils/crypto.ts";

const URL_INPUT_ID = "request-url";
const TEMPLATE = `<section>
      <details>
        <summary>How it Works</summary>
        <ul>
          <li>Send the generated URL below to whom you wish to request data from.</li>
          <li>Upon accessing the URL, the receiver can then enter the data you'd like from them.</li>
          <li>This generates a URL that they'll send back to you.</li>
          <li>You can now access the encrypted data in the URL which only _your_ browser can decrypt.</li>
        </ul>
      </details>

      <form>
        <input
          type="text"
          name="request-url"
          id="${URL_INPUT_ID}"
          placeholder=""
          aria-label="Request URL"
          required
        />
      </form>
    </section>`;

export async function setupRequestPage(element: HTMLElement) {
  element.innerHTML = TEMPLATE;

  const url = await generateUrl();
  const input = document.getElementById(URL_INPUT_ID) as HTMLInputElement;
  input.value = url.toString();
}

async function generateUrl(): Promise<URL> {
  const { publicKey: ecdhPublic } = await retrieveOrGenerateKeyPair();

  // Generate URL with public key as the 'p' search parameter
  const ecdhPublicJwk = await window.crypto.subtle.exportKey("jwk", ecdhPublic);
  const url = new URL(window.location.toString());
  url.hash = `p=${btoa(JSON.stringify(ecdhPublicJwk))}`;

  // Return the generated URL
  return url;
}
